@@ -6,7 +6,7 @@ import matplotlib.pyplot as plt
 class objearth():
     def __init__(self,DataArray):
         self.DataArray = DataArray
-        
+
     def plotshow(self,lst=True):
         self.lst = lst
         if type(self.DataArray) == xarray.core.dataarray.DataArray:
@@ -67,6 +67,17 @@ class objearth():
         plt.show()
         return ndvi3
 
+    def percentcloud(self,Dataset):
+        self.Dataset = Dataset
+        FashCloud = [352,480,944]
+        dstest    = self.Dataset.pixel_qa
+        dsnew     = xarray.where(dstest == FashCloud[0],numpy.nan,dstest)
+        dsnew     = xarray.where(dsnew  == FashCloud[1],numpy.nan,dsnew)
+        dsnew     = xarray.where(dsnew  == FashCloud[2],numpy.nan,dsnew)
+        Cpixel    = (numpy.isnan(dsnew.to_numpy())).sum()
+        Allpixel  = int(self.Dataset.pixel_qa.count())
+        Cloudpercent = (Cpixel/Allpixel)*100
+        print("Percent Cloud : %.4f"%Cloudpercent,"%")
    
     
 
